@@ -27,8 +27,8 @@ class BaseDiff(BaseApi):
         e também as keys do nome e id
         """
 
-        self.__key_id = key_id
-        self.__key_name = key_name
+        self.key_id = key_id
+        self.key_name = key_name
         self.__item_name = item_name
 
         self.__url_update = url_update
@@ -40,14 +40,11 @@ class BaseDiff(BaseApi):
         self.__url_inactive = url_inactive
         self.__key_active = key_active
 
-        self.items = []
-        self.get_all()
-
     def create(self, data):
         """
         Adiciona um item ao sistema
         """
-        print("creating {} {}".format(data[self.__key_name], self.__item_name))
+        print("creating {} {}".format(data[self.key_name], self.__item_name))
         response = self.post(self.__url_create, data=data)
         self.status_ok(response)
 
@@ -58,9 +55,9 @@ class BaseDiff(BaseApi):
         """
         Atualiza os dados de um item já cadastrado no sistema
         """
-        print("updating {} {}".format(data[self.__key_name], self.__item_name))
+        print("updating {} {}".format(data[self.key_name], self.__item_name))
         response = self.put("{}/{}".format(self.__url_update,
-                                           data[self.__key_id]),
+                                           data[self.key_id]),
                             data=data)
         self.status_ok(response)
 
@@ -83,7 +80,7 @@ class BaseDiff(BaseApi):
         já cadastrados no sistema
         retorna True ou False
         """
-        detail = self.details(data[self.__key_id])
+        detail = self.details(data[self.key_id])
         cont = 0
         for key in data.keys():
             if detail[key] == data[key]:
@@ -99,16 +96,16 @@ class BaseDiff(BaseApi):
         então 'Isso' != 'isso'
 
         O parâmetro data é um dicionario
-        data = [self.__key_name: str]
+        data = [self.key_name: str]
         """
         for i in self.items:
-            if i[self.__key_name] == data[self.__key_name]:
-                return i[self.__key_id]
+            if i[self.key_name] == data[self.key_name]:
+                return i[self.key_id]
         return 0
 
     def search_item_by_name(self, nome):
         """
-        Pesquisa por um nome (self.__key_name) e retorna o Id (self.__key_id),
+        Pesquisa por um nome (self.key_name) e retorna o Id (self.key_id),
         a pesquisa é feita ignorando o case das letras e os acentos,
         então ISSó == iss
 
@@ -118,15 +115,18 @@ class BaseDiff(BaseApi):
         nome = deemphasize(nome)
         ids = []
         for i in self.items:
-            nome_item = deemphasize(i[self.__key_name])
+            nome_item = deemphasize(i[self.key_name])
             if re.search(nome, nome_item):
-                ids.append(i[self.__key_id])
+                ids.append(i[self.key_id])
 
         if len(ids) == 1:
             return ids[0]
 
-        print("{} {} not found!".format(self.__item_name, nome))
-        sys.exit(0)
+        if len(ids) == 0:
+            raise ValueError("{} {} not found!".format(self.__item_name, nome))
+        if len(ids) > 0:
+            raise ValueError("{} {} is duplicated!".format(
+                self.__item_name, nome))
 
     def details(self, item_id):
         """
@@ -143,18 +143,18 @@ class BaseDiff(BaseApi):
         se for igual, então o item é pulado,
         se tiver dados diferentes o item sera atualizado
         """
-        data[self.__key_id] = self.item_id(data)
+        data[self.key_id] = self.item_id(data)
 
-        if data[self.__key_id] == 0:
+        if data[self.key_id] == 0:
             item_id = self.create(data)
-            data[self.__key_id] = item_id
+            data[self.key_id] = item_id
             self.items.append(data)
 
         elif not self.equals(data):
             self.update(data)
 
         else:
-            print("skiping {} {}".format(data[self.__key_name],
+            print("skiping {} {}".format(data[self.key_name],
                                          self.__item_name))
 
     def delete(self, data):
@@ -162,16 +162,16 @@ class BaseDiff(BaseApi):
         Delete um item recebido por parametro (data),
         data tem que ter:
         data = [
-            self.__key_name: str,
-            self.__key_id: int
+            self.key_name: str,
+            self.key_id: int
         ]
         """
         if self.__url_delete is None:
             return False
 
-        print("deleting {} {}".format(data[self.__key_name], self.__item_name))
+        print("deleting {} {}".format(data[self.key_name], self.__item_name))
         response = super().delete("{}/{}".format(self.__url_delete,
-                                                 data[self.__key_id]))
+                                                 data[self.key_id]))
 
         return self.status_ok(response, erro_exit=False)
 
@@ -180,20 +180,20 @@ class BaseDiff(BaseApi):
             Inativa um item que é recebido por 'data'
             'data' deve ter:
             data = [
-                self.__key_name: str,
-                self.__key_id: int
+                self.key_name: str,
+                self.key_id: int
             ]
         """
         if self.__url_inactive is None:
             return False
 
-        data = self.details(data[self.__key_id])
+        data = self.details(data[self.key_id])
         data[self.__key_active] = False
 
-        print("inactivating {} {}".format(data[self.__key_name],
+        print("inactivating {} {}".format(data[self.key_name],
                                           self.__item_name))
         response = self.put("{}/{}".format(self.__url_inactive,
-                                           data[self.__key_id]),
+                                           data[self.key_id]),
                             data=data)
 
         return self.status_ok(response, erro_exit=False)
@@ -206,10 +206,11 @@ class BaseDiff(BaseApi):
         deleted = []
 
         for item in self.items:
+            if self.__url_inactive is not None:
+                self.inactive(item)
+
             if self.delete(item):
                 deleted.append(item)
-            else:
-                self.inactive(item)
 
         for i in deleted:
             self.items.remove(i)
