@@ -1,9 +1,12 @@
 from oneparams.api.base_diff import BaseDiff
-from oneparams.api.conta import conta
+from oneparams.api.conta import Conta
 from oneparams.api.operadora import Operadora
 
 
-class Card(BaseDiff):
+class apiCard(BaseDiff):
+    items = []
+    first_get = False
+
     def __init__(self):
         super().__init__(key_id="cartoesId",
                          key_name="descricao",
@@ -15,22 +18,25 @@ class Card(BaseDiff):
                          url_delete="/Cartoes")
 
         self.operadora = Operadora()
-        self.conta = conta()
+        self.conta = Conta()
+        if not apiCard.first_get:
+            self.get_all()
+            apiCard.first_get = True
 
     def get_all(self):
-        self.items = super().get_all()
+        apiCard.items = super().get_all()
 
     def details(self, item_id):
         return super().details(item_id)["cartoesLight"]
 
     def item_id(self, data):
-        for i in self.items:
+        for i in apiCard.items:
             if (i["descricao"] == data["descricao"]
                     and i["debito_Credito"] == data["debito_Credito"]):
                 return i["cartoesId"]
         return 0
 
-    def card(self, data):
+    def name_to_id(self, data):
         if "contasId" not in data.keys():
             data["contasId"] = self.conta.get_id(data["contas"])
             data.pop("contas")
@@ -38,5 +44,8 @@ class Card(BaseDiff):
             data["operadoraCartaoId"] = self.operadora.operator(
                 data["operadora"])
             data.pop("operadora")
+        return data
 
+    def card(self, data):
+        data = self.name_to_id(data)
         super().diff_item(data)
