@@ -4,22 +4,24 @@ import re
 from oneparams.api.base import BaseApi
 
 
-class conta(BaseApi):
+class Conta(BaseApi):
+    items = []
+    first_get = False
+
     def __init__(self):
-        self.__contas = []
-        self.all_contas()
+        if not Conta.first_get:
+            self.all_contas()
+            Conta.first_get = True
 
     def all_contas(self):
         print("researching accounts")
         response = self.get("/OContas/ListaContasDetalhes")
         self.status_ok(response)
 
-        content = json.loads(response.content)
-        for i in content:
-            self.__contas.append(i)
+        Conta.items = json.loads(response.content)
 
     def get_id(self, nome):
-        for i in self.__contas:
+        for i in Conta.items:
             if re.search(nome, i["nome"], re.IGNORECASE):
                 return i["contasId"]
         return None
