@@ -1,21 +1,24 @@
 import json
-import sys
 
 from oneparams.api.base import BaseApi
 from oneparams.utils import deemphasize, similar
 
 
 class Profissao(BaseApi):
+    items = []
+    first_get = False
+
     def __init__(self):
-        self.profissoes = []
-        self.get_all()
+        if not Profissao.first_get:
+            self.get_all()
+            Profissao.first_get = True
 
     def get_all(self):
         print("researching professions")
         response = self.get("/Profissoes/GetAllProfissoes")
         self.status_ok(response)
         content = json.loads(response.content)
-        self.profissoes = content
+        Profissao.items = content
 
     def profissao_id(self, nome):
         if nome is None:
@@ -23,16 +26,14 @@ class Profissao(BaseApi):
 
         nome = deemphasize(nome)
         len_similar = []
-        for profissao in self.profissoes:
+        for profissao in Profissao.items:
             pro = deemphasize(profissao["descricao"])
             len_similar.append(similar(nome, pro))
 
         max_similar = max(len_similar)
         if (max_similar < 0.6 or len_similar.count(max_similar) == 0):
-            print(f'profession {nome} not found!!')
-            sys.exit()
+            raise ValueError(f'profession {nome} not found!!')
         if len_similar.count(max_similar) > 1:
-            print(f'profession {nome} is duplicated!!')
-            sys.exit()
+            raise ValueError(f'profession {nome} is duplicated!!')
 
-        return self.profissoes[len_similar.index(max_similar)]["profissoesId"]
+        return Profissao.items[len_similar.index(max_similar)]["profissoesId"]
