@@ -3,10 +3,8 @@ import argparse
 import sys
 
 import xlrd
-from oneparams.api.cards import Card
-from oneparams.api.commission import Commission
+
 from oneparams.api.login import login
-from oneparams.api.servicos import Servicos
 from oneparams.args import parse_base
 from oneparams.excel.card import cards
 from oneparams.excel.colaborador import colaborador
@@ -66,33 +64,23 @@ def one():
               senha=args.password)
 
     if args.cmd == "serv":
-        if args.reset:
-            serv = Servicos()
-            serv.delete_all()
-        servico(book)
+        servico(book, reset=args.reset)
 
     if args.cmd == "cols":
         colaborador(book, args.app)
 
     if args.cmd == "card":
-        if args.reset:
-            cd = Card()
-            cd.delete_all()
-            cd.operadora.delete_all()
-        cards(book)
+        cards(book, reset=args.reset)
 
     if args.cmd == "comm":
-        if args.reset:
-            comm = Commission()
-            comm.delete_all()
-        comissao(book)
+        comissao(book, reset=args.reset)
 
 
 def main():
     try:
         one()
     except KeyboardInterrupt:
-        print("Quiting...")
+        print("\nQuiting...")
 
 
 if __name__ == "__main__":
